==> piwigo-11.5.0.zip: piwigo/language/nl_NL/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+

$lang['Installation'] = 'Installatie';
$lang['Basic configuration'] = 'Basis-configuratie';
$lang['Default gallery language'] = 'Standaard galerie-taal';
$lang['Database configuration'] = 'Database-configuratie';
$lang['Admin configuration'] = 'Beheer configuratie';
$lang['Start Install'] = 'Start Installatie';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Het wordt getoond aan de bezoekers. Het is ook noodzakelijk voor het beheer van de website';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'De verbinding met de server is geslaagd, maar het is niet mogelijk om verbinding te krijgen met de database';
$lang['Can\'t connect to server'] = 'Geen verbinding met de server';
$lang['Host'] = 'MySQL host';
$lang['User'] = 'Gebruiker';
$lang['user login given by your host provider'] = 'De gebruikersnaam die door jouw provider is gegeven';
$lang['user password given by your host provider'] = 'Wachtwoord dat door jouw provider is gegeven';
$lang['Database name'] = 'Database-naam';
$lang['also given by your host provider'] = 'Ook deze is door jouw provider gegeven';
$lang['Database table prefix'] = 'Database-tabel voorvoegsel';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'Tabellen in de database worden voorzien van dit voorvoegsel (dit maakt een beter beheer van de database mogelijk) ook wel prefix genoemd';
$lang['enter a login for webmaster'] = 'Geef de gebruikersnaam voor de beheerder';
$lang['webmaster login can\'t contain characters \' or "'] = 'De gebruikersnaam mag geen \' of " bevatten';
$lang['please enter your password again'] = 'Vul a.u.b. nog een keer je wachtwoord in';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Houd dit vertrouwelijk. Het geeft toegang tot de beheermodule';
$lang['Password [confirm]'] = 'Bevestig wachtwoord';
$lang['verification'] = 'controle';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Hulp nodig ? Stel je vraag op het <a href="%s" target="_blank">Piwigo forum</a>.';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Met dit email-adres kunnen bezoekers contact opnemen met de beheerder';
$lang['PHP 5 is required'] = 'PHP 5.2 is vereist';
$lang['It appears your webhost is currently running PHP %s.'] = 'Het lijkt er op dat je webhost momenteel gebruik maakt van PHP %s.';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo kan proberen je configuratie om te zetten naar PHP 5.2 door het aanmaken of wijzigen van een .htaccess bestand.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Opmerking: je kunt je configuratie ook zelf aanpassen en daarna Piwigo opnieuw opstarten.';
$lang['Try to configure PHP 5'] = 'Probeer PHP 5.2 te configureren';
$lang['Sorry!'] = 'Sorry!';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo kon PHP 5.2 niet configureren.';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Neem contact op met de support van je hosting provider en probeer met hen te bepalen hoe je kunt omschakelen naar PHP 5.2';
$lang['Hope to see you back soon.'] = 'Hoop je snel weer te zien op deze site!';
$lang['Congratulations, Piwigo installation is completed'] = 'Gefeliciteerd, de Piwigo installatie is afgerond';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Als alternatieve oplossing kun je de tekst in de bovenstaande box kopiëren en plakken in bestand "local/config/database.inc.php" (Opgelet : in database.inc.php mag alleen datgene staan dat in het tekstgebied staat, geen return- of spatie-tekens)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Het aanmaken van config-bestand local/config/database.inc.php is mislukt.';
$lang['Download the config file'] = 'Download het config-bestand';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Je kunt het config-bestand downloaden en het uploaden naar de local/config directory van jouw Piwigo-installatie.';
$lang['Just another Piwigo gallery'] = 'Alweer een Piwigo galerie';
$lang['Welcome to my photo gallery'] = 'Welkom bij mijn fotogalerie';
$lang['Welcome to your new installation of Piwigo!'] = 'Welkom bij jouw nieuwe installatie van Piwigo!';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Aarzel niet om onze forums te raadplegen voor hulp: %s';
$lang['localhost or other, supplied by your host provider'] = 'localhost of andere, geleverd door je provider';

==> piwigo-12.2.0.zip: piwigo/language/nl_NL/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+

$lang['Installation'] = 'Installatie';
$lang['Basic configuration'] = 'Basis-configuratie';
$lang['Default gallery language'] = 'Standaard galerie-taal';
$lang['Database configuration'] = 'Database-configuratie';
$lang['Admin configuration'] = 'Beheer configuratie';
$lang['Start Install'] = 'Start Installatie';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Het wordt getoond aan de bezoekers. Het is ook noodzakelijk voor het beheer van de website';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'De verbinding met de server is geslaagd, maar het is niet mogelijk om verbinding te krijgen met de database';
$lang['Can\'t connect to server'] = 'Geen verbinding met de server';
$lang['Host'] = 'MySQL host';
$lang['User'] = 'Gebruiker';
$lang['user login given by your host provider'] = 'De gebruikersnaam die door jouw provider is gegeven';
$lang['user password given by your host provider'] = 'Wachtwoord dat door jouw provider is gegeven';
$lang['Database name'] = 'Database-naam';
$lang['also given by your host provider'] = 'Ook deze is door jouw provider gegeven';
$lang['Database table prefix'] = 'Database-tabel voorvoegsel';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'Tabellen in de database worden voorzien van dit voorvoegsel (dit maakt een beter beheer van de database mogelijk) ook wel prefix genoemd';
$lang['enter a login for webmaster'] = 'Geef de gebruikersnaam voor de beheerder';
$lang['webmaster login can\'t contain characters \' or "'] = 'De gebruikersnaam mag geen \' of " bevatten';
$lang['please enter your password again'] = 'Vul a.u.b. nog een keer jouw wachtwoord in';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Houd dit vertrouwelijk. Het geeft toegang tot de beheermodule';
$lang['Password [confirm]'] = 'Bevestig wachtwoord';
$lang['verification'] = 'controle';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Hulp nodig ? Stel je vraag op het <a href="%s" target="_blank">Piwigo forum</a>.';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Met dit email-adres kunnen bezoekers contact opnemen met de beheerder';
$lang['PHP 5 is required'] = 'PHP 5.2 is vereist';
$lang['It appears your webhost is currently running PHP %s.'] = 'Het lijkt er op dat je webhost momenteel gebruik maakt van PHP %s.';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo kan proberen je configuratie om te zetten naar PHP 5.2 door het aanmaken of wijzigen van een .htaccess bestand.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Opmerking: je kunt je configuratie ook zelf aanpassen en daarna Piwigo opnieuw opstarten.';
$lang['Try to configure PHP 5'] = 'Probeer PHP 5.2 te configureren';
$lang['Sorry!'] = 'Sorry!';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo kon PHP 5.2 niet configureren.';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Neem contact op met de support van je hosting provider en probeer met hen te bepalen hoe je kunt omschakelen naar PHP 5.2';
$lang['Hope to see you back soon.'] = 'Hoop je snel weer te zien op deze site!';
$lang['Congratulations, Piwigo installation is completed'] = 'Gefeliciteerd, de Piwigo installatie is afgerond';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Als alternatieve oplossing kun je de tekst in de bovenstaande box kopiëren en plakken in bestand "local/config/database.inc.php" (Opgelet : in database.inc.php mag alleen datgene staan dat in het tekstgebied staat, geen return- of spatie-tekens)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Het aanmaken van config-bestand local/config/database.inc.php is mislukt.';
$lang['Download the config file'] = 'Download het config-bestand';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Je kunt het config-bestand downloaden en het uploaden naar de local/config directory van jouw Piwigo-installatie.';
$lang['Just another Piwigo gallery'] = 'Alweer een Piwigo galerie';
$lang['Welcome to my photo gallery'] = 'Welkom bij mijn fotogalerie';
$lang['Welcome to your new installation of Piwigo!'] = 'Welkom bij jouw nieuwe installatie van Piwigo!';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Aarzel niet om onze forums te raadplegen voor hulp: %s';
$lang['localhost or other, supplied by your host provider'] = 'localhost of andere, geleverd door je provider';
